@@ -17,9 +17,13 @@ G_BEGIN_DECLS
 #define EPHY_TYPE_URI_CHECK_TYPE ad_uri_check_type_get_type()
 GType ad_uri_check_type_get_type (void);
 
-/* --- ephy-embed-persist.h --- */
-#define EPHY_TYPE_EMBED_PERSIST_FLAGS ephy_embed_persist_flags_get_type()
-GType ephy_embed_persist_flags_get_type (void);
+/* --- ephy-download.h --- */
+#define EPHY_TYPE_DOWNLOAD_ACTION_TYPE ephy_download_action_type_get_type()
+GType ephy_download_action_type_get_type (void);
+
+/* --- ephy-embed-shell.h --- */
+#define EPHY_TYPE_EMBED_SHELL_MODE ephy_embed_shell_mode_get_type()
+GType ephy_embed_shell_mode_get_type (void);
 
 /* --- ephy-permission-manager.h --- */
 #define EPHY_TYPE_PERMISSION ephy_permission_get_type()
@@ -28,14 +32,14 @@ GType ephy_permission_get_type (void);
 /* --- ephy-web-view.h --- */
 #define EPHY_TYPE_WEB_VIEW_NAVIGATION_FLAGS ephy_web_view_navigation_flags_get_type()
 GType ephy_web_view_navigation_flags_get_type (void);
-#define EPHY_TYPE_WEB_VIEW_NET_STATE ephy_web_view_net_state_get_type()
-GType ephy_web_view_net_state_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_CHROME ephy_web_view_chrome_get_type()
 GType ephy_web_view_chrome_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_SECURITY_LEVEL ephy_web_view_security_level_get_type()
 GType ephy_web_view_security_level_get_type (void);
 #define EPHY_TYPE_WEB_VIEW_DOCUMENT_TYPE ephy_web_view_document_type_get_type()
 GType ephy_web_view_document_type_get_type (void);
+#define EPHY_TYPE_WEB_VIEW_ERROR_PAGE ephy_web_view_error_page_get_type()
+GType ephy_web_view_error_page_get_type (void);
 G_END_DECLS
 
 #endif /* EPHY_EMBED_TYPE_BUILTINS_H */
